@@ -42,7 +42,9 @@ if __name__ == "__main__":
             print('DAMAXCONTENTLENGTH=' + str(max_content_length))
     else:
         print('DAMAXCONTENTLENGTH=' + str(16 * 1024 * 1024))
-    if 'debian packages' in daconfig and type(daconfig['debian packages']) is list:
+    if 'celery processes' in daconfig and isinstance(daconfig['celery processes'], int):
+        print('DACELERYWORKERS=' + str(daconfig['celery processes']))
+    if 'debian packages' in daconfig and isinstance(daconfig['debian packages'], list):
         print('declare -a PACKAGES')
         print('export PACKAGES')
         indexno = 0
@@ -116,6 +118,8 @@ if __name__ == "__main__":
         print('export DAEXPOSEWEBSOCKETS=true')
     if 'websockets ip' in daconfig and daconfig['websockets ip']:
         print('export DAWEBSOCKETSIP="' + str(daconfig['websockets ip']) + '"')
+    if 'http port' in daconfig and daconfig['http port']:
+        print('export PORT="' + str(daconfig['http port']) + '"')
     if 'stable version' in daconfig and daconfig['stable version']:
         print('export DASTABLEVERSION=true')
     if 'nginx ssl protocols' in daconfig and daconfig['nginx ssl protocols']:
